DBUS_DBUS_BUSNAME       = "org.freedesktop.DBus"
DBUS_DBUS_IFACE         = "org.freedesktop.DBus"
DBUS_DBUS_OBJPATH       = "/org/freedesktop/DBus"

DBUS_SYNCENGINE_BUSNAME = "org.synce.SyncEngine"
DBUS_SYNCENGINE_IFACE   = "org.synce.SyncEngine"
DBUS_SYNCENGINE_OBJPATH = "/org/synce/SyncEngine"

DBUS_SYNCEKPM_DATASERVER_BUSNAME = "org.synce.kpm.dataserver"
DBUS_SYNCEKPM_DATASERVER_IFACE   = "org.synce.kpm.DataServerInterface"
DBUS_SYNCEKPM_DATASERVER_OBJPATH = "/org/synce/kpm/DataServer"

DBUS_SYNCEKPM_GUI_BUSNAME = "org.synce.kpm.gui"
DBUS_SYNCEKPM_GUI_IFACE   = "org.synce.kpm.GuiInterface"
DBUS_SYNCEKPM_GUI_OBJPATH = "/org/synce/kpm/Gui"

ODCCM_DEVICE_PASSWORD_FLAG_SET               = 1
ODCCM_DEVICE_PASSWORD_FLAG_PROVIDE           = 2
ODCCM_DEVICE_PASSWORD_FLAG_PROVIDE_ON_DEVICE = 4

SYNCE_DEVICE_PASSWORD_FLAG_UNSET             = "unset"
SYNCE_DEVICE_PASSWORD_FLAG_PROVIDE           = "provide"
SYNCE_DEVICE_PASSWORD_FLAG_PROVIDE_ON_DEVICE = "provide-on-device"
SYNCE_DEVICE_PASSWORD_FLAG_CHECKING          = "checking"
SYNCE_DEVICE_PASSWORD_FLAG_UNLOCKED          = "unlocked"

